@@ -8,7 +8,7 @@ use NBI::Opts;
 use base qw(Exporter);
 our @ISA = qw(Exporter);
 our @EXPORT = qw(Job Opts load_config has_queue %FORMAT_STRINGS);
-$NBI::Slurm::VERSION = '0.8.6';
+$NBI::Slurm::VERSION = '0.9.0';
 
 
 
@@ -71,12 +71,16 @@ sub has_squeue {
 sub queues {
   my $can_fail = shift;
   # Retrieve queues from SLURM
-  my $has_sinfo = `sinfo --version`;
-  chomp($has_sinfo);
+  my $has_sinfo = undef;
+  eval {
+    $has_sinfo = `sinfo --version > /dev/null 2>&1`;
+  };
+  
+  chomp($has_sinfo) if defined $has_sinfo;
   if (not defined $has_sinfo and ! $can_fail) {
     Carp::croak "ERROR NBI::Slurm: sinfo failed. Are you in a SLURM cluster?\n";
   }
-  my $cmd = "sinfo --format '%P' --noheader";
+  my $cmd = "timeout 5s sinfo --format '%P' --noheader";
   my @output = `$cmd 2>/dev/null`;
   if ($? != 0 and ! $can_fail) {
     Carp::croak "ERROR NBI::Slurm: sinfo did not find queues. Are you in a SLURM cluster?\n";
@@ -87,9 +91,17 @@ sub queues {
 }
 
 sub valid_queue {
+  if ($ENV{'SKIP_SLURM_CHECK'}) {
+    return 1;
+  }
   my $queue = shift;
   my @queues = queues('CAN_FAIL');
   my @input_queues = split(/,/, $queue);
+
+  if (scalar(@input_queues) == 0) {
+    # Let's assume it exists... TODO CHECK
+    return  1;
+  }
   foreach my $input_queue (@input_queues) {
     if (! grep { $_ eq $input_queue } @queues) {
       return 0;
@@ -141,7 +153,7 @@ NBI::Slurm - NBI Slurm module
 
 =head1 VERSION
 
-version 0.8.6
+version 0.9.0
 
 =head1 SYNOPSIS
 
